﻿using Syncfusion.UI.Xaml.Charts;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Shapes;

namespace PieChart
{
    public class PieSeriesExt : PieSeries
    {

        public PieSeriesExt()
            : base()
        {

        }

        /// <summary>
        /// Contains a set of colors to outline each segment with a specific color.
        /// </summary>
        public List<Brush> StrokeBrsuhes
        {
            get { return (List<Brush>)GetValue(StrokeBrsuhesProperty); }
            set { SetValue(StrokeBrsuhesProperty, value); }
        }

        // Using a DependencyProperty as the backing store for StrokeBrsuhes.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty StrokeBrsuhesProperty =
            DependencyProperty.Register("StrokeBrsuhes", typeof(List<Brush>), typeof(PieSeriesExt), new PropertyMetadata(new List<Brush>()));

        public override void CreateSegments()
        {
            // Clears the adornments.
            Adornments.Clear();

            // Creates the pie segments and adornments.
            base.CreateSegments();
            
            //Applies the stroke palette to pie segments.
            ApplyStroke();
        }

        /// <summary>
        /// Overriden to apply the stroke palette on initial update.
        /// </summary>
        protected override void OnApplyTemplate()
        {
            base.OnApplyTemplate();
            //Applies the stroke palette to pie segments.
            ApplyStroke();
        }

        /// <summary>
        /// Applies the stroke palette to segments.
        /// </summary>
        void ApplyStroke()
        {
            foreach (var item in this.Segments)
            {
                var path = item.GetRenderedVisual() as Shape;
                if (path != null)
                    path.Stroke = GetBrush(this.Segments.IndexOf(item));
            }
        }

        /// <summary>
        /// Returns the brush to be used for each segment.
        /// </summary>
        /// <param name="colorIndex"> indesx of the segment</param>
        /// <returns>return brush</returns>
        public Brush GetBrush(int colorIndex)
        {
            return this.StrokeBrsuhes[colorIndex % StrokeBrsuhes.Count()];
        }
    }
}
